@@ -7,7 +7,10 @@ import psycopg2
 
 
 class PreSQL():
-    def __init__(self, dbname=None, user=None, password=None, host=None, port=None):
+    def __init__(self, uri=None, dbname=None, user=None, password=None, host=None, port=None, sslmode=None):
+        # https://www.psycopg.org/docs/connection.html
+        self.uri = uri
+        self.dbname = dbname
         self.dbname = dbname
         self.user = user
         self.password = password
@@ -17,25 +20,38 @@ class PreSQL():
         self.cursor = None
  
     def __enter__(self):
-        if not isinstance(self.dbname, str) and isinstance(self.user, str) and isinstance(self.password, str):
-            assert False, "Database parameters mus be in string format."
-        if isinstance(self.host, str) and isinstance(self.port, str):
-            self.connection = psycopg2.connect(dbname=self.dbname,
-                                               user=self.user,
-                                               password=self.password,
-                                               host=self.host,
-                                               port=self.port)
-        else:
-            self.connection = psycopg2.connect(dbname=self.dbname,
-                                               user=self.user,
-                                               password=self.password)
-        if self.connection is not None:
-            self.cursor = self.connection.cursor()
+        if not isinstance(self.uri, str):
+            if not (isinstance(self.dbname, str) and isinstance(self.user, str) and isinstance(self.password, str)):
+                assert False, "Database parameters must be in string format."
+                return
+        try:
+            if isinstance(self.uri, str):
+                if not isinstance(self.sslmode, str):
+                    self.connection = psycopg2.connect(self.uri)
+                else:
+                    self.connection = psycopg2.connect(self.uri, sslmode=self.sslmode)
+            elif isinstance(self.host, str) and isinstance(self.port, str):
+                self.connection = psycopg2.connect(dbname=self.dbname,
+                                                    user=self.user,
+                                                    password=self.password,
+                                                    host=self.host,
+                                                    port=self.port)
+            else:
+                self.connection = psycopg2.connect(dbname=self.dbname,
+                                                user=self.user,
+                                                password=self.password)
+            if self.connection is not None:
+                self.cursor = self.connection.cursor()
+        except:
+            pass
         return self
     
     def set_client_encoding(self, encoding):
         if self.connection is not None:
             self.connection.set_client_encoding(encoding)
+    
+    def connected(self):
+        return (self.connection is not None)
         
     def execute(self, query, values=None):
         result = None
@@ -63,10 +79,10 @@ class PreSQL():
         conditions = ""
         if not isinstance(where, str) or where is None:
             conditions = f"WHERE {where}"
-        rows = self.execute(f"SELECT COUNT(col) FROM {table} {conditions};")
+        rows = self.execute(f"SELECT COUNT({column}) FROM {table} {conditions};")
         if rows is not None:
             for row in rows.fetchone():
-                return int(row["usage"])
+                return int(row["COUNT"])
         return 0
     
     def select(self,
